package client;

/**
 * Represents an online user with all the information that is needed
 * by the client.
 */
class User {
	/* User details */
	private String name;
	private byte[] ip;
	private int port;

	User(String name, byte[] ip, int port) {
		this.name = name;
		this.ip = ip;
		this.port = port;
	}

	public String getName() {
		return name;
	}

	public byte[] getIP() {
		return ip;
	}

	public int getPort() {
		return port;
	}

	/**
	 * Returns a string as "name @ 129.132.130.158:6789".
	 */
	public String toString() {
		StringBuffer result = new StringBuffer();
		result.append(name);
		result.append(" @ ");
		result.append(showIP());
		result.append(":");
		result.append(port);

		return result.toString();
	}

	public String showIP() {
		StringBuffer result = new StringBuffer();
		for (int i = 0; i < 4; i++) {
			result.append((int)ip[i] & 0xff);
			if (i < 3)
				result.append(".");
		}

		return result.toString();
	}

	/**
	 * Returns true, if name, ip and port are equal.
	 */
	public boolean equals(Object obj) {
		if ((obj == null) || !(obj instanceof User))
			return false;

		User user = (User)obj;
		return name.equals(user.getName()) && ipEquals(ip, user.getIP()) && (port == user.getPort());
	}

	/**
	 * Returns true, if ip1[0] == ip2[0], ip1[1] == ip2[1], ...
	 */
	private boolean ipEquals(byte[] ip1, byte[] ip2) {
		for (int i = 0; i < ip1.length; i++) {
			if (ip1[i] != ip2[i])
				return false;
		}
		return true;
	}
}